@@ -14,14 +14,16 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef __GSL_MATRIX_ULONG_H__
 #define __GSL_MATRIX_ULONG_H__
 
 #include <stdlib.h>
+#include <gsl/gsl_types.h>
 #include <gsl/gsl_errno.h>
+#include <gsl/gsl_check_range.h>
 #include <gsl/gsl_vector_ulong.h>
 
 #undef __BEGIN_DECLS
@@ -202,7 +204,7 @@ int gsl_matrix_ulong_fscanf (FILE * stream, gsl_matrix_ulong * m);
 int gsl_matrix_ulong_fprintf (FILE * stream, const gsl_matrix_ulong * m, const char * format);
  
 int gsl_matrix_ulong_memcpy(gsl_matrix_ulong * dest, const gsl_matrix_ulong * src);
-int gsl_matrix_ulong_swap(gsl_matrix_ulong * m1, const gsl_matrix_ulong * m2);
+int gsl_matrix_ulong_swap(gsl_matrix_ulong * m1, gsl_matrix_ulong * m2);
 
 int gsl_matrix_ulong_swap_rows(gsl_matrix_ulong * m, const size_t i, const size_t j);
 int gsl_matrix_ulong_swap_columns(gsl_matrix_ulong * m, const size_t i, const size_t j);
@@ -226,6 +228,7 @@ int gsl_matrix_ulong_mul_elements (gsl_matrix_ulong * a, const gsl_matrix_ulong
 int gsl_matrix_ulong_div_elements (gsl_matrix_ulong * a, const gsl_matrix_ulong * b);
 int gsl_matrix_ulong_scale (gsl_matrix_ulong * a, const double x);
 int gsl_matrix_ulong_add_constant (gsl_matrix_ulong * a, const double x);
+int gsl_matrix_ulong_add_diagonal (gsl_matrix_ulong * a, const double x);
 
 /***********************************************************************/
 /* The functions below are obsolete                                    */
@@ -235,8 +238,6 @@ int gsl_matrix_ulong_get_col(gsl_vector_ulong * v, const gsl_matrix_ulong * m, c
 int gsl_matrix_ulong_set_row(gsl_matrix_ulong * m, const size_t i, const gsl_vector_ulong * v);
 int gsl_matrix_ulong_set_col(gsl_matrix_ulong * m, const size_t j, const gsl_vector_ulong * v);
 
-extern int gsl_check_range ;
-
 /* inline functions if you are using GCC */
 
 #ifdef HAVE_INLINE
@@ -244,7 +245,7 @@ extern inline
 unsigned long
 gsl_matrix_ulong_get(const gsl_matrix_ulong * m, const size_t i, const size_t j)
 {
-#ifndef GSL_RANGE_CHECK_OFF
+#if GSL_RANGE_CHECK
   if (i >= m->size1)
     {
       GSL_ERROR_VAL("first index out of range", GSL_EINVAL, 0) ;
@@ -261,7 +262,7 @@ extern inline
 void
 gsl_matrix_ulong_set(gsl_matrix_ulong * m, const size_t i, const size_t j, const unsigned long x)
 {
-#ifndef GSL_RANGE_CHECK_OFF
+#if GSL_RANGE_CHECK
   if (i >= m->size1)
     {
       GSL_ERROR_VOID("first index out of range", GSL_EINVAL) ;
@@ -278,7 +279,7 @@ extern inline
 unsigned long *
 gsl_matrix_ulong_ptr(gsl_matrix_ulong * m, const size_t i, const size_t j)
 {
-#ifndef GSL_RANGE_CHECK_OFF
+#if GSL_RANGE_CHECK
   if (i >= m->size1)
     {
       GSL_ERROR_NULL("first index out of range", GSL_EINVAL) ;
@@ -295,7 +296,7 @@ extern inline
 const unsigned long *
 gsl_matrix_ulong_const_ptr(const gsl_matrix_ulong * m, const size_t i, const size_t j)
 {
-#ifndef GSL_RANGE_CHECK_OFF
+#if GSL_RANGE_CHECK
   if (i >= m->size1)
     {
       GSL_ERROR_NULL("first index out of range", GSL_EINVAL) ;
